<!--
Copyright (c) 2022-2023 Geosiris.
SPDX-License-Identifier: Apache-2.0
-->
Energyml types
==============

[![License](https://img.shields.io/pypi/l/resqml22)](https://github.com/geosiris-technologies/energyml-python-generator/blob/main/LICENSE)
[![Documentation Status](https://readthedocs.org/projects/energyml-python-generator/badge/?version=latest)](https://energyml-python-generator.readthedocs.io/en/latest/?badge=latest)
![Python version](https://img.shields.io/pypi/pyversions/resqml22)
![Status](https://img.shields.io/pypi/status/resqml22)




Installation
------------

Multiple projects are generated: 

- resqml22
- resqml201
- resqml22dev3
- witml20
- witsml21
- prodml22

Energyml-types can be installed with pip : 

```console
pip install energyml-common2_0
```

or with poetry: 
```console
poetry add energyml-common2_0
```
